Index: chrome/browser/cocoa/content_exceptions_window_controller.h |
diff --git a/chrome/browser/cocoa/content_exceptions_window_controller.h b/chrome/browser/cocoa/content_exceptions_window_controller.h |
index 131cf72f27d96647155cc26366296369fb37f829..5c012f3bdfcffc1eea71e3e047df52bb8699cccf 100644 |
--- a/chrome/browser/cocoa/content_exceptions_window_controller.h |
+++ b/chrome/browser/cocoa/content_exceptions_window_controller.h |
@@ -31,8 +31,8 @@ class UpdatingContentSettingsObserver; |
HostContentSettingsMap* otrSettingsMap_; // weak |
scoped_ptr<ContentExceptionsTableModel> model_; |
- // Is set if "Ask" should be a valid option in the "action" popup. |
- BOOL showAsk_; |
+ // Is set if "Session" should be a valid option in the "action" popup. |
+ BOOL showSession_; |
// Is set if adding and editing exceptions for the current OTR session should |
// be allowed. |